Skip to content

AP Suite XML analysisset file format

AP Suite/IVAS offers some functionalities that store analysis metadata in XML files, a situation similar to earlier IVAS versions. Nowadays, though the file name extension used is analysisset. In the spirit of the Imago XML parser, we also implemented a simple parser that shows how ranging definitions can be extracted from such XML files.

analysisset NeXus/HDF5
Ranging definitions ✔️