Skip to content

AMETEK/Cameca HDF5 file format

As another example of recent modernization work within the file format landscape for atom probe, we offer a parser that maps results from a recent work of machine-learning-based ranging of mass spectra onto NeXus/HDF5.

HDF5 NeXus/HDF5
Reconstructed positions (x, y, z) ✔️
Mass-to-charge-state-ratio values (m/q) ✔️
Ranging definitions ✔️