Skip to content

Imago/AMETEK/Cameca/IVAS XML analysis file format

Imago IVAS, the forerunner software of AP Suite/IVAS stored analysis state metadata and some data in XML files with the file name extension analysis. As an example, we implemented a simple parser that shows how ranging definitions can be extracted from such XML files.

analysis NeXus/HDF5
Ranging definitions ✔️